@@ -1,4 +1,5 @@
 /*PGR-GNU*****************************************************************
+File: hawickcircuits.hpp
 
 Copyright (c) 2022 pgRouting developers
 Mail: project@pgrouting.org
@@ -37,9 +38,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <boost/graph/hawick_circuits.hpp>
 
 #include "cpp_common/basePath_SSEC.hpp"
-#include "cpp_common/pgr_base_graph.hpp"
-#include "cpp_common/interruption.h"
-#include "cpp_common/pgr_assert.h"
+#include "cpp_common/base_graph.hpp"
+#include "cpp_common/interruption.hpp"
+#include "cpp_common/assert.hpp"
 #include "c_types/circuits_rt.h"
 
 /**
