@@ -31,7 +31,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define INCLUDE_CPP_COMMON_BASIC_EDGE_HPP_
 #pragma once
 
-#include <stdint.h>
+#include <cstdint>
 
 namespace pgrouting {
 
