@@ -30,17 +30,27 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define INCLUDE_DRIVERS_CONTRACTION_CONTRACTGRAPH_DRIVER_H_
 #pragma once
 
-/* for size-t */
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+#include <postgres.h>
+#include <utils/array.h>
+
+#ifdef __cplusplus
+}
+#endif
+
+#include "cpp_common/undefPostgresDefine.hpp"
+
 #ifdef __cplusplus
 #   include <cstdint>
 #   include <cstddef>
 using contracted_rt = struct contracted_rt;
-using Edge_t = struct Edge_t;
 #else
 #   include <stdint.h>
 #   include <stddef.h>
 typedef struct contracted_rt contracted_rt;
-typedef struct Edge_t Edge_t;
 #endif
 
 
@@ -48,29 +58,14 @@ typedef struct Edge_t Edge_t;
 extern "C" {
 #endif
 
-    /*********************************************************
-        edges_sql TEXT,
-        contraction_order BIGINT[],
-        forbidden_vertices BIGINT[] DEFAULT ARRAY[]::BIGINT[],
-        max_cycles integer DEFAULT 1,
-        directed BOOLEAN DEFAULT true
-     ********************************************************/
-    void
-        do_pgr_contractGraph(
-               Edge_t  *data_edges,
-        size_t total_tuples,
-        int64_t *forbidden_vertices,
-        size_t size_forbidden_vertices,
-        int64_t *contraction_order,
-        size_t size_contraction_order,
-        int64_t max_cycles,
-        bool directed,
-        contracted_rt **return_tuples,
-        size_t *return_count,
-        char **log_msg,
-        char **notice_msg,
-        char **err_msg);
+void pgr_do_contractGraph(
+        char*,
+        ArrayType*, ArrayType*,
 
+        int64_t, bool,
+
+        contracted_rt**, size_t*,
+        char**, char**, char**);
 
 #ifdef __cplusplus
 }
