@@ -32,31 +32,39 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define INCLUDE_DRIVERS_YEN_KSP_DRIVER_H_
 #pragma once
 
-/* for size-t */
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+#include <postgres.h>
+#include <utils/array.h>
+
+#ifdef __cplusplus
+}
+#endif
+
+#include "cpp_common/undefPostgresDefine.hpp"
+
 #ifdef __cplusplus
 #   include <cstdint>
 #   include <cstddef>
-using Edge_t = struct Edge_t;
 using Path_rt = struct Path_rt;
-using II_t_rt = struct II_t_rt;
 #else
 #   include <stddef.h>
 #   include <stdint.h>
-typedef struct Edge_t Edge_t;
 typedef struct Path_rt Path_rt;
-typedef struct II_t_rt II_t_rt;
 #endif
 
-
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 void  pgr_do_ksp(
-        Edge_t*, size_t,
-        II_t_rt*, size_t,
-        int64_t*, size_t,
-        int64_t*, size_t,
+        char*,
+        char*,
+        ArrayType*, ArrayType*,
+        int64_t*,
+        int64_t*,
         size_t,
         bool,
         bool,
