@@ -33,46 +33,51 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define INCLUDE_DRIVERS_YEN_WITHPOINTS_KSP_DRIVER_H_
 #pragma once
 
-/* for size-t */
-#ifdef __cplusplus
-#   include <cstdint>
-#   include <cstddef>
-using Point_on_edge_t = struct Point_on_edge_t;
-using Edge_t = struct Edge_t;
-using Path_rt = struct Path_rt;
-using II_t_rt = struct II_t_rt;
-#else
-#   include <stddef.h>
-#   include <stdint.h>
-typedef struct Point_on_edge_t Point_on_edge_t;
-typedef struct Edge_t Edge_t;
-typedef struct Path_rt Path_rt;
-#endif
-
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-    int pgr_do_withPointsKsp(
-            Edge_t*,           size_t,
-            Point_on_edge_t*,  size_t,
-            Edge_t*,           size_t,
-
-            II_t_rt*, size_t,
-            int64_t*, size_t,
-            int64_t*, size_t,
-            size_t,
-            bool, bool,
-            char,
-            bool,
-
-            Path_rt**, size_t*,
-            char**, char**, char**);
-
+#include <postgres.h>
+#include <utils/array.h>
 
 #ifdef __cplusplus
-    }
+}
+#endif
+
+#include "cpp_common/undefPostgresDefine.hpp"
+
+#ifdef __cplusplus
+#   include <cstddef>
+#   include <cstdint>
+using Path_rt = struct Path_rt;
+#else
+#   include <stddef.h>
+#   include <stdint.h>
+typedef struct Path_rt Path_rt;
+#endif
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
+void pgr_do_withPointsKsp(
+        char*,
+        char*,
+        char*,
+        char*,
+        ArrayType*, ArrayType*,
+        int64_t*, int64_t*,
+        size_t,
+
+bool, bool, char, bool,
+
+        Path_rt**, size_t*,
+        char**, char**, char**);
+
+#ifdef __cplusplus
+}
 #endif
 
 #endif  // INCLUDE_DRIVERS_YEN_WITHPOINTS_KSP_DRIVER_H_
