@@ -21,7 +21,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 /*
 .. function:: _pgr_pointToId(point geometry, tolerance double precision,vname text,srid integer)
 Using tolerance to determine if its an existing point:
@@ -39,7 +39,8 @@ Last changes: 2013-03-22
 2013-08-19: handling schemas
 */
 
-CREATE OR REPLACE FUNCTION _pgr_pointToId(
+--v2.6
+CREATE FUNCTION _pgr_pointToId(
     point geometry,
     tolerance double precision,
     vertname text,
@@ -79,3 +80,6 @@ END;
 $BODY$
 LANGUAGE plpgsql VOLATILE STRICT;
 
+COMMENT ON FUNCTION _pgr_pointToId(geometry, FLOAT, TEXT, INTEGER)
+IS 'pgRouting internal function';
+
