@@ -29,7 +29,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 -------------------
 
 -- ONE to ONE
-CREATE OR REPLACE FUNCTION pgr_dijkstraCost(
+--v2.6
+CREATE FUNCTION pgr_dijkstraCost(
     TEXT,   -- edges_sql (required)
     BIGINT, -- from_vids (required)
     BIGINT, -- to_vids (required)
@@ -51,7 +52,8 @@ ROWS 1000;
 
 
 -- ONE to MANY
-CREATE OR REPLACE FUNCTION pgr_dijkstraCost(
+--v2.6
+CREATE FUNCTION pgr_dijkstraCost(
     TEXT,     -- edges_sql (required)
     BIGINT,   -- from_vid (required)
     ANYARRAY, -- to_vids (required)
@@ -74,7 +76,8 @@ ROWS 1000;
 
 
 -- MANY to ONE
-CREATE OR REPLACE FUNCTION pgr_dijkstraCost(
+--v2.6
+CREATE FUNCTION pgr_dijkstraCost(
     TEXT,     -- edges_sql (required)
     ANYARRAY, -- from_vids (required)
     BIGINT,   -- to_vid (required)
@@ -97,7 +100,8 @@ ROWS 1000;
 
 
 -- MANY to MANY
-CREATE OR REPLACE FUNCTION pgr_dijkstraCost(
+--v2.6
+CREATE FUNCTION pgr_dijkstraCost(
     TEXT,     -- edges_sql (required)
     ANYARRAY, -- from_vids (required)
     ANYARRAY, -- to_vids (required)
@@ -117,7 +121,8 @@ COST 100
 ROWS 1000;
 
 -- Combinations SQL signature
-CREATE OR REPLACE FUNCTION pgr_dijkstraCost(
+--v3.1
+CREATE FUNCTION pgr_dijkstraCost(
     TEXT,     -- edges_sql (required)
     TEXT,     -- combinations_sql (required)
 
@@ -147,7 +152,7 @@ IS 'pgr_dijkstraCost(One to One)
 - Optional Parameters
    - directed := true
 - Documentation:
-   - ${PGROUTING_DOC_LINK}/pgr_dijkstraCost.html
+   - ${PROJECT_DOC_LINK}/pgr_dijkstraCost.html
 ';
 
 COMMENT ON FUNCTION pgr_dijkstraCost(TEXT, BIGINT, ANYARRAY, BOOLEAN)
@@ -159,7 +164,7 @@ IS 'pgr_dijkstraCost(One to Many)
 - Optional Parameters
    - directed := true
 - Documentation:
-   - ${PGROUTING_DOC_LINK}/pgr_dijkstraCost.html
+   - ${PROJECT_DOC_LINK}/pgr_dijkstraCost.html
 ';
 
 COMMENT ON FUNCTION pgr_dijkstraCost(TEXT, ANYARRAY, BIGINT, BOOLEAN)
@@ -171,7 +176,7 @@ IS 'pgr_dijkstraCost(Many to One)
 - Optional Parameters
    - directed := true
 - Documentation:
-   - ${PGROUTING_DOC_LINK}/pgr_dijkstraCost.html
+   - ${PROJECT_DOC_LINK}/pgr_dijkstraCost.html
 ';
 
 COMMENT ON FUNCTION pgr_dijkstraCost(TEXT, ANYARRAY, ANYARRAY, BOOLEAN)
@@ -183,7 +188,7 @@ IS 'pgr_dijkstraCost(Many to Many)
 - Optional Parameters
    - directed := true
 - Documentation:
-   - ${PGROUTING_DOC_LINK}/pgr_dijkstraCost.html
+   - ${PROJECT_DOC_LINK}/pgr_dijkstraCost.html
 ';
 
 COMMENT ON FUNCTION pgr_dijkstraCost(TEXT, TEXT, BOOLEAN)
@@ -194,5 +199,5 @@ IS 'pgr_dijkstraCost(Combinations SQL)
 - Optional Parameters
    - directed := true
 - Documentation:
-   - ${PGROUTING_DOC_LINK}/pgr_dijkstraCost.html
+   - ${PROJECT_DOC_LINK}/pgr_dijkstraCost.html
 ';
