@@ -1,4 +1,27 @@
 #!/usr/bin/perl -w
+=pod
+
+Copyright (c) 2015 pgRouting developers
+Mail: project@pgrouting.org
+
+------
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+
+=cut
+
 eval 'exec /usr/bin/perl -S $0 ${1+"$@"}'
     if 0; #$running_under_some_shell
 
@@ -6,13 +29,13 @@ eval 'exec /usr/bin/perl -S $0 ${1+"$@"}'
 # Almost files in the src/*/sql are part of the extension
 # The files indicated on the CMakelists of the subdirectory:
 # Are going to be included (when not commented out)
-# The generated file is going to be used to compare VS the generated file on cmake
+# Used on cmake
 
 use strict;
 use Data::Dumper;
 use File::Find();
 
-my $DEBUG="@PgRouting_DEBUG@";
+my $DEBUG="@PROJECT_DEBUG@";
 
 use vars qw/*name *dir *prune/;
 *name   = *File::Find::name;
@@ -26,17 +49,17 @@ sub Usage {
 }
 
 
-my $version = "@PGROUTING_VERSION@";
+my $version = "@PROJECT_VERSION@";
 my $working_directory = "@CMAKE_CURRENT_BINARY_DIR@/..";
-my $PgRouting_SQL_FILES =  "@PgRouting_SQL_FILES@";
-my @sql_file = split(/;/, $PgRouting_SQL_FILES);
-my $out_file_name = "$working_directory/@PgRouting_CURRENT_SQL_FILE@";
+my $PROJECT_SQL_FILES =  "@PROJECT_SQL_FILES@";
+my @sql_file = split(/;/, $PROJECT_SQL_FILES);
+my $out_file_name = "$working_directory/@PROJECT_EXTENSION_FILE@";
 
-print "Working_directory $working_directory\n"      if $DEBUG;
-print "out_file_name $out_file_name\n"      if $DEBUG;
+print "Working directory $working_directory\n"      if $DEBUG;
+print "Output file name $out_file_name\n"      if $DEBUG;
 
 open(OUT, ">", "$out_file_name")
-    || die "@PgRouting_CURRENT_SQL_FILE@ ERROR: failed to create: '$out_file_name' : $!\n";
+    || die "@PROJECT_EXTENSION_FILE@ ERROR: failed to create: '$out_file_name' : $!\n";
 
 foreach my $f (@sql_file) {
     print "--  $f\n" if $DEBUG;
