@@ -55,7 +55,7 @@ CREATE FUNCTION pgr_TSPeuclidean(
     OUT agg_cost FLOAT)
 RETURNS SETOF RECORD AS
 $BODY$
-    SELECT *
+    SELECT seq, node, cost, agg_cost
     FROM _pgr_TSPeuclidean(_pgr_get_statement($1), $2,$3, $4, $5,$6,$7, $8,$9,$10, $11);
 $BODY$
 LANGUAGE SQL VOLATILE STRICT
