@@ -73,7 +73,7 @@ pgr_do_alphaShape(
         char **notice_msg,
         char **err_msg) {
     using pgrouting::pgr_alloc;
-    using pgrouting::pgr_msg;
+    using pgrouting::to_pg_msg;
     using pgrouting::pgr_free;
 
     std::ostringstream log;
@@ -180,7 +180,7 @@ pgr_do_alphaShape(
             *return_tuples = pgr_alloc(*return_count, (*return_tuples));
             std::stringstream ss;
             ss << "MULTIPOLYGON EMPTY";
-            (*return_tuples)[0].geom = pgr_msg(ss.str().c_str());
+            (*return_tuples)[0].geom = to_pg_msg(ss.str());
         } else {
             *return_count = results.size();
             *return_tuples = pgr_alloc(*return_count, (*return_tuples));
@@ -188,38 +188,34 @@ pgr_do_alphaShape(
             for (const auto &r : results) {
                 std::stringstream ss;
                 ss << bg::wkt(r);
-                (*return_tuples)[row].geom = pgr_msg(ss.str().c_str());
+                (*return_tuples)[row].geom = to_pg_msg(ss.str());
                 ++row;
             }
         }
 
 
-        *log_msg = log.str().empty()?
-            *log_msg :
-            pgr_msg(log.str().c_str());
-        *notice_msg = notice.str().empty()?
-            *notice_msg :
-            pgr_msg(notice.str().c_str());
+        *log_msg = to_pg_msg(log);
+        *notice_msg = to_pg_msg(notice);
     } catch (AssertFailedException &except) {
         (*return_tuples) = pgr_free(*return_tuples);
         (*return_count) = 0;
         err << except.what();
-        *err_msg = pgr_msg(err.str().c_str());
-        *log_msg = pgr_msg(log.str().c_str());
+        *err_msg = to_pg_msg(err);
+        *log_msg = to_pg_msg(log);
     } catch (const std::string &ex) {
-        *err_msg = pgr_msg(ex.c_str());
-        *log_msg = hint? pgr_msg(hint) : pgr_msg(log.str().c_str());
+        *err_msg = to_pg_msg(ex);
+        *log_msg = hint? to_pg_msg(hint) : to_pg_msg(log);
     } catch (std::exception &except) {
         (*return_tuples) = pgr_free(*return_tuples);
         (*return_count) = 0;
         err << except.what();
-        *err_msg = pgr_msg(err.str().c_str());
-        *log_msg = pgr_msg(log.str().c_str());
+        *err_msg = to_pg_msg(err);
+        *log_msg = to_pg_msg(log);
     } catch(...) {
         (*return_tuples) = pgr_free(*return_tuples);
         (*return_count) = 0;
         err << "Caught unknown exception!";
-        *err_msg = pgr_msg(err.str().c_str());
-        *log_msg = pgr_msg(log.str().c_str());
+        *err_msg = to_pg_msg(err);
+        *log_msg = to_pg_msg(log);
     }
 }
