@@ -1,6 +1,5 @@
 /*PGR-GNU*****************************************************************
-
-FILE: solution.cpp
+File: solution.cpp
 
 Copyright (c) 2015 pgRouting developers
 Mail: project@pgrouting.org
@@ -23,15 +22,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  ********************************************************************PGR-GNU*/
 
-#include "vrp/solution.h"
+#include "vrp/solution.hpp"
 
 #include <vector>
 #include <string>
 #include <algorithm>
 
-#include "c_types/pickDeliver/schedule_rt.h"
+#include "c_types/schedule_rt.h"
 
-#include "vrp/pgr_pickDeliver.h"
+#include "vrp/pickDeliver.hpp"
 
 
 namespace pgrouting {
