@@ -1,5 +1,4 @@
 /*PGR-GNU*****************************************************************
-
 File: GraphDefinition.cpp
 
 Copyright (c) 2015 pgRouting developers
@@ -23,14 +22,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  ********************************************************************PGR-GNU*/
 
-#include "trsp/GraphDefinition.h"
+#include "trsp/GraphDefinition.hpp"
 
 #include <utility>
 #include <queue>
 #include <vector>
 #include <functional>
 
-#include "c_types/edge_t.h"
+#include "c_types/edge_rt.h"
 
 // -------------------------------------------------------------------------
 GraphDefinition::GraphDefinition(void) {
