@@ -31,7 +31,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include "c_common/debug_macro.h"
 #include "c_common/e_report.h"
 #include "c_common/time_msg.h"
-#include "c_common/pgdata_getters.h"
 #include "drivers/trsp/trspVia_driver.h"
 
 PGDLLEXPORT Datum _pgr_trspvia(PG_FUNCTION_ARGS);
@@ -42,7 +41,7 @@ void
 process(
         char* edges_sql,
         char* restrictions_sql,
-        ArrayType *via_arr,
+        ArrayType *vias,
         bool directed,
         bool strict,
         bool U_turn_on_edge,
@@ -53,32 +52,11 @@ process(
     char* notice_msg = NULL;
     char* err_msg = NULL;
 
-    size_t size_via = 0;
-    int64_t* via = pgr_get_bigIntArray(&size_via, via_arr, false, &err_msg);
-    throw_error(err_msg, "While getting via vertices");
-
-    Edge_t* edges = NULL;
-    size_t size_edges = 0;
-    pgr_get_edges(edges_sql, &edges, &size_edges, true, false, &err_msg);
-    throw_error(err_msg, edges_sql);
-
-    if (size_edges == 0) {
-        if (via) pfree(via);
-        pgr_SPI_finish();
-        return;
-    }
-
-    Restriction_t * restrictions = NULL;
-    size_t size_restrictions = 0;
-
-    pgr_get_restrictions(restrictions_sql, &restrictions, &size_restrictions, &err_msg);
-    throw_error(err_msg, restrictions_sql);
-
     clock_t start_t = clock();
-    do_trspVia(
-            edges, size_edges,
-            restrictions, size_restrictions,
-            via, size_via,
+    pgr_do_trspVia(
+            edges_sql,
+            restrictions_sql,
+            vias,
             directed,
             strict,
             U_turn_on_edge,
@@ -95,14 +73,8 @@ process(
         (*result_count) = 0;
     }
 
-    pgr_global_report(log_msg, notice_msg, err_msg);
+    pgr_global_report(&log_msg, &notice_msg, &err_msg);
 
-    if (log_msg) {pfree(log_msg); log_msg = NULL;}
-    if (notice_msg) {pfree(notice_msg); notice_msg = NULL;}
-    if (err_msg) {pfree(err_msg); err_msg = NULL;}
-    if (edges) {pfree(edges); edges = NULL;}
-    if (via) {pfree(via); via = NULL;}
-    if (restrictions) {pfree(restrictions); restrictions = NULL;}
     pgr_SPI_finish();
 }
 
@@ -112,25 +84,14 @@ _pgr_trspvia(PG_FUNCTION_ARGS) {
     FuncCallContext     *funcctx;
     TupleDesc            tuple_desc;
 
-    /**********************************************************************/
     Routes_t  *result_tuples = 0;
     size_t result_count = 0;
-    /**********************************************************************/
 
     if (SRF_IS_FIRSTCALL()) {
         MemoryContext   oldcontext;
         funcctx = SRF_FIRSTCALL_INIT();
         oldcontext = MemoryContextSwitchTo(funcctx->multi_call_memory_ctx);
 
-
-        /**********************************************************************
-         * pgr_trspVia(edges_sql text,
-         *   vertices anyarray,
-         *   directed boolean default true,
-         *   strict boolean default false,
-         *   U_turn_on_edge boolean default false,
-         **********************************************************************/
-
         process(
                 text_to_cstring(PG_GETARG_TEXT_P(0)),
                 text_to_cstring(PG_GETARG_TEXT_P(1)),
@@ -141,8 +102,6 @@ _pgr_trspvia(PG_FUNCTION_ARGS) {
                 &result_tuples,
                 &result_count);
 
-        /**********************************************************************/
-
         funcctx->max_calls = result_count;
 
         funcctx->user_fctx = result_tuples;
@@ -168,20 +127,6 @@ _pgr_trspvia(PG_FUNCTION_ARGS) {
         bool*        nulls;
         size_t       call_cntr = funcctx->call_cntr;
 
-        /**********************************************************************/
-        /*
-           OUT seq INTEGER,
-           OUT path_id INTEGER,
-           OUT path_seq INTEGER,
-           OUT start_vid BIGINT,
-           OUT end_vid BIGINT,
-           OUT node BIGINT,
-           OUT edge BIGINT,
-           OUT cost FLOAT,
-           OUT agg_cost FLOAT,
-           OUT route_agg_cost FLOAT
-           */
-
         size_t numb_out = 10;
         values = palloc(numb_out * sizeof(Datum));
         nulls = palloc(numb_out * sizeof(bool));
@@ -190,7 +135,6 @@ _pgr_trspvia(PG_FUNCTION_ARGS) {
             nulls[i] = false;
         }
 
-        // postgres starts counting from 1
         values[0] = Int32GetDatum((int32_t)call_cntr + 1);
         values[1] = Int32GetDatum(result_tuples[call_cntr].path_id);
         values[2] = Int32GetDatum(result_tuples[call_cntr].path_seq + 1);
@@ -202,8 +146,6 @@ _pgr_trspvia(PG_FUNCTION_ARGS) {
         values[8] = Float8GetDatum(result_tuples[call_cntr].agg_cost);
         values[9] = Float8GetDatum(result_tuples[call_cntr].route_agg_cost);
 
-        /**********************************************************************/
-
         tuple = heap_form_tuple(tuple_desc, values, nulls);
         result = HeapTupleGetDatum(tuple);
         SRF_RETURN_NEXT(funcctx, result);
