@@ -151,7 +151,7 @@ pgr_do_trspVia_withPoints(
         char** err_msg) {
     using pgrouting::Path;
     using pgrouting::pgr_alloc;
-    using pgrouting::pgr_msg;
+    using pgrouting::to_pg_msg;
     using pgrouting::pgr_free;
     using pgrouting::pgget::get_intArray;
 
@@ -179,8 +179,8 @@ pgr_do_trspVia_withPoints(
         auto edges = pgrouting::pgget::get_edges(std::string(edges_sql), true, false);
 
         if (edges.size() + edges_of_points.size() == 0) {
-            *notice_msg = pgr_msg("No edges found");
-            *log_msg = hint? pgr_msg(hint) : pgr_msg(log.str().c_str());
+            *notice_msg = to_pg_msg("No edges found");
+            *log_msg = hint? to_pg_msg(hint) : to_pg_msg(log);
             return;
         }
 
@@ -199,8 +199,8 @@ pgr_do_trspVia_withPoints(
         if (pg_graph.has_error()) {
             log << pg_graph.get_log();
             err << pg_graph.get_error();
-            *log_msg = pgr_msg(log.str().c_str());
-            *err_msg = pgr_msg(err.str().c_str());
+            *log_msg = to_pg_msg(log);
+            *err_msg = to_pg_msg(err);
             return;
         }
 
@@ -240,7 +240,7 @@ pgr_do_trspVia_withPoints(
 
         if (count == 0) {
             notice << "No paths found";
-            *log_msg = pgr_msg(notice.str().c_str());
+            *log_msg = to_pg_msg(notice);
             return;
         }
 
@@ -287,32 +287,28 @@ pgr_do_trspVia_withPoints(
         (*return_count) = (get_route(return_tuples, paths));
         (*return_tuples)[count - 1].edge = -2;
 
-        *log_msg = log.str().empty()?
-            *log_msg :
-            pgr_msg(log.str().c_str());
-        *notice_msg = notice.str().empty()?
-            *notice_msg :
-            pgr_msg(notice.str().c_str());
+        *log_msg = to_pg_msg(log);
+        *notice_msg = to_pg_msg(notice);
     } catch (AssertFailedException &except) {
         (*return_tuples) = pgr_free(*return_tuples);
         (*return_count) = 0;
         err << except.what();
-        *err_msg = pgr_msg(err.str().c_str());
-        *log_msg = pgr_msg(log.str().c_str());
+        *err_msg = to_pg_msg(err);
+        *log_msg = to_pg_msg(log);
     } catch (const std::string &ex) {
-        *err_msg = pgr_msg(ex.c_str());
-        *log_msg = hint? pgr_msg(hint) : pgr_msg(log.str().c_str());
+        *err_msg = to_pg_msg(ex);
+        *log_msg = hint? to_pg_msg(hint) : to_pg_msg(log);
     } catch (std::exception &except) {
         (*return_tuples) = pgr_free(*return_tuples);
         (*return_count) = 0;
         err << except.what();
-        *err_msg = pgr_msg(err.str().c_str());
-        *log_msg = pgr_msg(log.str().c_str());
+        *err_msg = to_pg_msg(err);
+        *log_msg = to_pg_msg(log);
     } catch(...) {
         (*return_tuples) = pgr_free(*return_tuples);
         (*return_count) = 0;
         err << "Caught unknown exception!";
-        *err_msg = pgr_msg(err.str().c_str());
-        *log_msg = pgr_msg(log.str().c_str());
+        *err_msg = to_pg_msg(err);
+        *log_msg = to_pg_msg(log);
     }
 }
