@@ -1,6 +1,5 @@
 /*PGR-GNU*****************************************************************
-
-File: tsp.cc
+File: tsp.cpp
 
 Copyright (c) 2021 pgRouting developers
 Mail: project@pgrouting.org
@@ -41,9 +40,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <boost/version.hpp>
 
 #include "cpp_common/identifiers.hpp"
-#include "cpp_common/pgr_messages.h"
-#include "cpp_common/pgr_assert.h"
-#include "cpp_common/interruption.h"
+#include "cpp_common/messages.hpp"
+#include "cpp_common/assert.hpp"
+#include "cpp_common/interruption.hpp"
 
 #include "visitors/dijkstra_visitors.hpp"
 
@@ -231,7 +230,7 @@ TSP::tsp(
     auto u = get_boost_vertex(start_vid);
     auto v = get_boost_vertex(end_vid);
 
-    auto dummy_node = add_vertex(num_vertices(graph), graph);
+    auto dummy_node = add_vertex(static_cast<int>(num_vertices(graph)), graph);
     id_to_V.insert(std::make_pair(0, dummy_node));
     V_to_id.insert(std::make_pair(dummy_node, 0));
     boost::add_edge(u, dummy_node, 0, graph);
@@ -283,27 +282,25 @@ TSP::crossover_optimize(std::deque<std::pair<int64_t, double>> result, size_t li
 
 
 
-TSP::TSP(
-    IID_t_rt *distances,
-    size_t total_distances, bool) {
+TSP::TSP(std::vector<IID_t_rt> &distances) {
     /*
      * Inserting vertices
      */
     Identifiers<int64_t> ids;
-    for (size_t i = 0; i < total_distances; ++i) {
-        ids += distances[i].from_vid;
-        ids += distances[i].to_vid;
+    for (auto &d : distances) {
+        ids += d.from_vid;
+        ids += d.to_vid;
         /*
          * Its undirected graph:
          * keeping from_vid < to_vid
          */
-        if (distances[i].to_vid > distances[i].from_vid) {
-            std::swap(distances[i].to_vid, distances[i].from_vid);
+        if (d.to_vid > d.from_vid) {
+            std::swap(d.to_vid, d.from_vid);
         }
     }
 
-    size_t i {0};
-    for (const auto id : ids) {
+    int i {0};
+    for (const auto &id : ids) {
         auto v = add_vertex(i, graph);
         id_to_V.insert(std::make_pair(id, v));
         V_to_id.insert(std::make_pair(v, id));
@@ -313,8 +310,7 @@ TSP::TSP(
     /*
      * Inserting edges
      */
-    for (size_t i = 0; i < total_distances; ++i) {
-        auto edge = distances[i];
+    for (const auto &edge : distances) {
         /*
          * skip loops
          */
@@ -374,24 +370,22 @@ TSP::TSP(
  * 2 , 3.6 1
  * but when the remove_duplicates flag is on, keep only the first row that has the same id
  */
-TSP::TSP(Coordinate_t *coordinates,
-        size_t total_coordinates,
-        bool ) {
-    log << "before total_coordinates" << total_coordinates;
+TSP::TSP(const std::vector<Coordinate_t> &coordinates) {
+    log << "before total_coordinates" << coordinates.size();
 
     /*
      * keeping the vertex identifiers
      */
     Identifiers<int64_t> ids;
-    for (size_t i = 0; i < total_coordinates; ++i) {
-        ids += coordinates[i].id;
+    for (const auto c : coordinates) {
+        ids += c.id;
     }
 
     /*
      * Inserting vertices
      */
-    size_t i{0};
-    for (const auto id : ids) {
+    int i{0};
+    for (const auto &id : ids) {
         auto v = add_vertex(i, graph);
         id_to_V.insert(std::make_pair(id, v));
         V_to_id.insert(std::make_pair(v, id));
@@ -401,7 +395,7 @@ TSP::TSP(Coordinate_t *coordinates,
     /*
      * Inserting edges
      */
-    for (size_t i = 0; i < total_coordinates; ++i) {
+    for (size_t i = 0; i < coordinates.size(); ++i) {
         auto u = get_boost_vertex(coordinates[i].id);
         auto ux = coordinates[i].x;
         auto uy = coordinates[i].y;
@@ -409,7 +403,7 @@ TSP::TSP(Coordinate_t *coordinates,
         /*
          *  undirected, so only need traverse higher coordinates for connections
          */
-        for (size_t j = i + 1; j < total_coordinates; ++j) {
+        for (size_t j = i + 1; j < coordinates.size(); ++j) {
             auto v = get_boost_vertex(coordinates[j].id);
 
             /*
@@ -438,7 +432,6 @@ TSP::TSP(Coordinate_t *coordinates,
 
 
 
-
 std::deque<std::pair<int64_t, double>>
 TSP::eval_tour(const std::vector<V> &tsp_tour) {
     std::deque<std::pair<int64_t, double>> results;
@@ -517,14 +510,6 @@ std::ostream& operator<<(std::ostream &log, const TSP& data) {
     log << "Number of Edges is:" << num_edges(data.graph) << "\n";
     log << "\n the print_graph\n";
     boost::print_graph(data.graph, boost::get(boost::vertex_index, data.graph), log);
-#if 0
-    // to print with edge weights:
-    for (auto v : boost::make_iterator_range(boost::vertices(data.graph))) {
-        for (auto oe : boost::make_iterator_range(boost::out_edges(v, data.graph))) {
-            log << "Edge " << oe << " weight " << get(boost::edge_weight, data.graph)[oe] << "\n";
-        }
-    }
-#endif
     return log;
 }
 #endif
